Learn R Programming

maestro (version 1.3.0)

.run_sequence_min_days_out: Minimum days ahead to pre-compute run sequences on initialization This small window is used at parse time; the full window is built lazily when observability functions (get_run_sequence, get_slot_usage) are called.

Description

Minimum days ahead to pre-compute run sequences on initialization This small window is used at parse time; the full window is built lazily when observability functions (get_run_sequence, get_slot_usage) are called.

Usage

.run_sequence_min_days_out(unit)

Value

integer

Arguments

unit

character frequency unit