| MaestroPipelineList | R Documentation |
Class for a list of MaestroPipelines A MaestroPipelineList is created when there are multiple maestro pipelines in a single script
MaestroPipelineslist of pipelines
n_pipelinesnumber of pipelines in the list
MaestroPipelineList$new()Create a MaestroPipelineList object
MaestroPipelineList$new(MaestroPipelines = list(), network = NULL)
MaestroPipelineslist of MaestroPipelines
networkinitialize a network
MaestroPipelineList
MaestroPipelineList$print()Print the MaestroPipelineList
MaestroPipelineList$print()
MaestroPipelineList$add_pipelines()Add pipelines to the list
MaestroPipelineList$add_pipelines(MaestroPipelines = NULL)
MaestroPipelineslist of MaestroPipelines
invisible
MaestroPipelineList$update_pipelines()Update pipelines in a list
MaestroPipelineList$update_pipelines(MaestroPipelines = NULL)
MaestroPipelineslist of MaestroPipelines
invisible
MaestroPipelineList$get_pipe_names()Get names of the pipelines in the list arranged by priority
MaestroPipelineList$get_pipe_names()
character
MaestroPipelineList$get_pipe_by_name()Get a MaestroPipeline by its name
MaestroPipelineList$get_pipe_by_name(pipe_name)
pipe_namename of the pipeline
MaestroPipeline
MaestroPipelineList$get_pipes_by_name()Get a MaestroPipelineList with selected pipelines
MaestroPipelineList$get_pipes_by_name(pipe_names)
pipe_namesnames of the pipelines
MaestroPipelineList
MaestroPipelineList$get_priorities()Get priorities
MaestroPipelineList$get_priorities()
numeric
MaestroPipelineList$get_schedule()Get the schedule as a data.frame
MaestroPipelineList$get_schedule()
data.frame
MaestroPipelineList$get_timely_pipelines()Get a new MaestroPipelineList containing only those pipelines scheduled to run
MaestroPipelineList$get_timely_pipelines(...)
...arguments passed to self$check_timeliness
MaestroPipelineList
MaestroPipelineList$get_primary_pipes()Get pipelines that are primary (i.e., don't have an inputting pipeline)
MaestroPipelineList$get_primary_pipes()
list of MaestroPipelines
MaestroPipelineList$check_timeliness()Check whether pipelines in the list are scheduled to run based on orchestrator frequency and current time
MaestroPipelineList$check_timeliness(...)
...arguments passed to self$check_timeliness
logical
MaestroPipelineList$get_status()Get status of the pipelines as a data.frame
MaestroPipelineList$get_status()
data.frame
MaestroPipelineList$get_errors()Get list of errors from the pipelines
MaestroPipelineList$get_errors()
list
MaestroPipelineList$get_warnings()Get list of warnings from the pipelines
MaestroPipelineList$get_warnings()
list
MaestroPipelineList$get_messages()Get list of messages from the pipelines
MaestroPipelineList$get_messages()
list
MaestroPipelineList$get_artifacts()Get artifacts (return values) from the pipelines
MaestroPipelineList$get_artifacts()
list
MaestroPipelineList$get_run_sequences()Get run sequences from the pipelines
MaestroPipelineList$get_run_sequences( n = NULL, min_datetime = NULL, max_datetime = NULL )
noptional sequence limit
min_datetimeoptional minimum datetime
max_datetimeoptional maximum datetime
list
MaestroPipelineList$get_flags()Get the flags of the pipelines as a named list
MaestroPipelineList$get_flags()
list
MaestroPipelineList$get_labels()Get the labels of the pipelines as a data.frame
MaestroPipelineList$get_labels()
data.frame
MaestroPipelineList$get_network()Get the network structure as a edge list
MaestroPipelineList$get_network()
data.frame
MaestroPipelineList$validate_network()Validates whether all inputs and outputs exist and that the network is a valid DAG
MaestroPipelineList$validate_network()
warning or invisible
MaestroPipelineList$run()Runs all the pipelines in the list
MaestroPipelineList$run(..., cores = 1L, pipes_to_run = NULL)
...arguments passed to MaestroPipeline$run
coresif using multicore number of cores to run in (uses furrr)
pipes_to_runan optional vector of pipe names to run. If NULL defaults to all primary pipelines
invisible
MaestroPipelineList$run_pending_collects()Run any collect pipelines that are ready but were skipped during a parallel run. Called on the main process after update_pipelines() has synced worker state back. Uses run_pipe internally so that the collect pipe's own downstream outputs are recursed into normally.
MaestroPipelineList$run_pending_collects(...)
...arguments forwarded to MaestroPipeline$run (same dots as run())
list of MaestroPipeline objects that were run
MaestroPipelineList$reset_pipelines()Resets the run time attributes
MaestroPipelineList$reset_pipelines()
MaestroPipelineList$clone()The objects of this class are cloneable with this method.
MaestroPipelineList$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.