View source: R/build_schedule.R
| build_schedule | R Documentation |
Builds a MaestroSchedule object for use in run_schedule().
build_schedule(pipeline_dir = "./pipelines", cores = 1L, quiet = FALSE)
pipeline_dir |
path to directory containing the pipeline scripts |
cores |
number of cpu cores to use when parsing pipeline scripts. If > 1,
|
quiet |
silence metrics to the console (default = |
This function parses the maestro tags of functions located in pipeline_dir which is
conventionally called 'pipelines'. An orchestrator requires a MaestroSchedule
to determine which pipelines are to run and when. Each pipeline in the schedule
is a parsed function and its scheduling parameters such as its frequency.
The MaestroSchedule is mostly intended to be passed directly to run_schedule().
In other words, it is not recommended to make changes to it.
MaestroSchedule
# Creating a temporary directory for demo purposes! In practice, just
# create a 'pipelines' directory at the project level.
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
build_schedule(pipeline_dir = pipeline_dir)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.