build_schedule_entry: Parse and validate tags then create and populate...

View source: R/build_schedule_entry.R

build_schedule_entryR Documentation

Parse and validate tags then create and populate MaestroPipelineList

Description

Parse and validate tags then create and populate MaestroPipelineList

Usage

build_schedule_entry(script_path)

Arguments

script_path

path to script

Value

MaestroPipelineList R6 class


maestro documentation built on July 2, 2026, 5:07 p.m.