View source: R/create_maestro.R
| create_maestro | R Documentation |
Creates a new maestro project
create_maestro(path, type = "R", overwrite = FALSE, quiet = FALSE, ...)
path |
file path for the orchestrator script |
type |
file type for the orchestrator (supports R, Quarto, and RMarkdown) |
overwrite |
whether to overwrite an existing orchestrator or maestro project |
quiet |
whether to silence messages in the console (default = |
... |
unused |
invisible
# Creates a new maestro project with an R orchestrator
if (interactive()) {
new_proj_dir <- tempdir()
create_maestro(new_proj_dir, type = "R", overwrite = TRUE)
create_maestro(new_proj_dir, type = "Quarto", overwrite = TRUE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.