| .run_sequence_days_out | R Documentation |
Number of days ahead to generate run sequences for a given frequency unit Used by the observable get_run_sequence path.
.run_sequence_days_out(unit)
unit |
character frequency unit |
integer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.