get_run_sequence: Get the run sequence of a schedule

View source: R/get_run_sequence.R

get_run_sequenceR Documentation

Get the run sequence of a schedule

Description

Retrieves the scheduled run times for a given schedule, with optional filtering by number of runs and datetime range.

Usage

get_run_sequence(
  schedule,
  n = NULL,
  min_datetime = NULL,
  max_datetime = NULL,
  include_only_primary = FALSE,
  include_skipped = TRUE
)

Arguments

schedule

object of type MaestroSchedule created using build_schedule()

n

Optional positive integer. If specified, returns only the first n runs for each pipeline.

min_datetime

Optional minimum datetime filter. Can be a Date or POSIXct object. If specified, only returns runs scheduled at or after this datetime.

max_datetime

Optional maximum datetime filter. Can be a Date or POSIXct object. If specified, only returns runs scheduled at or before this datetime.

include_only_primary

only primary pipelines are included (this are pipelines that are scheduled and not downstream nodes in a DAG)

include_skipped

whether to include pipelines tagged with ⁠@maestroSkip⁠ (default TRUE for backwards compatibility)

Value

A data.frame of scheduled run times with columns pipe_name, scheduled_time, and is_primary.

Examples

if (interactive()) {
  pipeline_dir <- tempdir()
  create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
  schedule <- build_schedule(pipeline_dir = pipeline_dir)

  get_run_sequence(schedule)

  # Alternatively, use the underlying R6 method
  schedule$get_run_sequence()
}

maestro documentation built on July 2, 2026, 5:07 p.m.