| invoke | R Documentation |
Instantly run a single pipeline from the schedule. This is useful for testing purposes or if you want to just run something one-off.
invoke(
schedule,
pipe_name,
resources = list(),
...,
quiet = TRUE,
log_to_console = FALSE
)
schedule |
object of type MaestroSchedule created using |
pipe_name |
name of a single pipe name from the schedule |
resources |
named list of shared resources made available to pipelines as needed |
... |
other arguments passed to |
quiet |
silence metrics to the console (default = |
log_to_console |
whether or not to include pipeline messages, warnings, errors to the console (default = |
Scheduling parameters such as the frequency, start time, and specifiers are ignored.
The pipeline will be run even if maestroSkip is present. If the pipeline is a DAG
pipeline, invoke will attempt to execute the full DAG.
invisible
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
invoke(schedule, "my_new_pipeline")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.