| MaestroSchedule | R Documentation |
Class for a schedule of pipelines
PipelineListobject of type MaestroPipelineList
MaestroSchedule$new()Create a MaestroSchedule object
MaestroSchedule$new(Pipelines = NULL)
Pipelineslist of MaestroPipelines
MaestroSchedule
MaestroSchedule$print()Print the schedule object
MaestroSchedule$print()
MaestroSchedule$run()Run a MaestroSchedule
MaestroSchedule$run(..., quiet = FALSE, run_all = FALSE, n_show_next = 5)
...arguments passed to MaestroPipelineList$run
quietwhether or not to silence console messages
run_allrun all pipelines regardless of the schedule (default is FALSE) - useful for testing.
n_show_nextshow the next n scheduled pipes
invisible
MaestroSchedule$get_schedule()Get the schedule as a data.frame
MaestroSchedule$get_schedule()
data.frame
MaestroSchedule$get_status()Get status of the pipelines as a data.frame
MaestroSchedule$get_status()
data.frame
MaestroSchedule$get_artifacts()Get artifacts (return values) from the pipelines
MaestroSchedule$get_artifacts()
list
MaestroSchedule$get_network()Get the network structure of the pipelines as an edge list (will be empty if there are no DAG pipelines)
MaestroSchedule$get_network()
data.frame
MaestroSchedule$get_flags()Get all pipeline flags as a long data.frame
MaestroSchedule$get_flags()
data.frame
MaestroSchedule$get_labels()Get all pipeline labels as a data.frame
MaestroSchedule$get_labels()
data.frame
MaestroSchedule$get_run_sequence()Get full sequence of scheduled executions for all pipelines
MaestroSchedule$get_run_sequence( n = NULL, min_datetime = NULL, max_datetime = NULL, include_only_primary = FALSE, include_skipped = TRUE )
noptional sequence limit
min_datetimeoptional minimum datetime
max_datetimeoptional maximum datetime
include_only_primaryonly primary pipelines are included (this are pipelines that are scheduled and not downstream nodes in a DAG)
include_skippedwhether to include pipelines tagged with @maestroSkip
(default TRUE for backwards compatibility)
data.frame
MaestroSchedule$clone()The objects of this class are cloneable with this method.
MaestroSchedule$clone(deep = FALSE)
deepWhether to make a deep clone.
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.