Class for a schedule of pipelines
Methods
MaestroSchedule$run()
Run a MaestroSchedule
MaestroSchedule$get_network()
Get the network structure of the pipelines as an edge list (will be empty if there are no DAG pipelines)
MaestroSchedule$get_run_sequence()
Get full sequence of scheduled executions for all pipelines
Usage
MaestroSchedule$get_run_sequence(
n = NULL,
min_datetime = NULL,
max_datetime = NULL,
include_only_primary = FALSE,
include_skipped = TRUE
)Arguments
noptional sequence limit
min_datetimeoptional minimum datetime
max_datetimeoptional maximum datetime
include_only_primaryonly primary pipelines are included (this are pipelines that are scheduled and not downstream nodes in a DAG)
include_skippedwhether to include pipelines tagged with
@maestroSkip(defaultTRUEfor backwards compatibility)
Examples
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
}