View source: R/get_artifacts.R
| get_artifacts | R Documentation |
Artifacts are return values from pipelines. They are accessible as a named list where the names correspond to the names of the pipeline.
get_artifacts(schedule)
schedule |
object of type MaestroSchedule created using |
named list
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
schedule <- run_schedule(
schedule,
orch_frequency = "1 day",
quiet = TRUE
)
get_artifacts(schedule)
# Alternatively, use the underlying R6 method
schedule$get_artifacts()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.