Get the network structure of pipelines in a MaestroSchedule object
Source:R/get_network.R
get_network.RdReturns the pipeline dependency structure as an edge list data.frame. Each row represents a directed dependency between two pipelines. The result will be empty if there are no DAG pipelines in the schedule.
Arguments
- schedule
object of type MaestroSchedule created using
build_schedule()
See also
show_network() which is deprecated in favour of this function.
Examples
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
get_network(schedule)
# Alternatively, use the underlying R6 method
schedule$get_network()
}