Learn R Programming

maestro (version 1.3.0)

get_network: Get the network structure of pipelines in a MaestroSchedule object

Description

Returns the pipeline dependency structure as an edge list data.frame. Each row represents a directed dependency between two pipelines. The result will be empty if there are no DAG pipelines in the schedule.

Usage

get_network(schedule)

Value

data.frame with columns from and to

Arguments

schedule

object of type MaestroSchedule created using build_schedule()

Examples

Run this code
if (interactive()) {
  pipeline_dir <- tempdir()
  create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
  schedule <- build_schedule(pipeline_dir = pipeline_dir)

  get_network(schedule)

  # Alternatively, use the underlying R6 method
  schedule$get_network()
}

Run the code above in your browser using DataLab