View source: R/get_run_sequence.R
| get_run_sequence | R Documentation |
Retrieves the scheduled run times for a given schedule, with optional filtering by number of runs and datetime range.
get_run_sequence(
schedule,
n = NULL,
min_datetime = NULL,
max_datetime = NULL,
include_only_primary = FALSE,
include_skipped = TRUE
)
schedule |
object of type MaestroSchedule created using |
n |
Optional positive integer. If specified, returns only the first |
min_datetime |
Optional minimum datetime filter. Can be a |
max_datetime |
Optional maximum datetime filter. Can be a |
include_only_primary |
only primary pipelines are included (this are pipelines that are scheduled and not downstream nodes in a DAG) |
include_skipped |
whether to include pipelines tagged with |
A data.frame of scheduled run times with columns pipe_name, scheduled_time,
and is_primary.
if (interactive()) {
pipeline_dir <- tempdir()
create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
schedule <- build_schedule(pipeline_dir = pipeline_dir)
get_run_sequence(schedule)
# Alternatively, use the underlying R6 method
schedule$get_run_sequence()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.